#include "mgos.h"

#ifdef MGOS_HAVE_DHT
#include "main.h"
#include "mgos_dht.h"
#include "mqtt.h"
static void dht_cb(void *ud) {
  struct mgos_dht *dht = (struct mgos_dht *)ud;
  float t, h;

  if (!dht) {
    LOG(LL_ERROR, ("No DHT handle to work with!"));
    return;
  }
  t = mgos_dht_get_temp(dht);
  h = mgos_dht_get_humidity(dht);

  mqtt_publish_stat("dht", "{temp=%.2f, humidity=%.1f}", t, h);
}

static void dht_create(int pin, enum dht_type type) {
  struct mgos_dht *dht;
  dht=mgos_dht_create(pin, type);
  if (!dht) {
    LOG(LL_ERROR, ("Could not create DHT sensor on pin %d", pin));
    return;
  }
  mgos_set_timer(5000, true, dht_cb, (void*)dht);
}

void dht_init() {
  dht_create(5, AM2302);
  mgos_msleep(250);
  dht_create(4, AM2302);
  mgos_msleep(250);
  dht_create(14, AM2302);
}

#else
void dht_init() {
  LOG(LL_INFO, ("DHT disabled, include library in mos.yml to enable"));
}
#endif
